@@ -1,10 +1,10 @@
 import logging
-from typing import List, Optional
+from typing import List, Optional, Union
 
 from curvenote.latex import utils
 
 from ..client import Session
-from ..models import BlockFormat, BlockKind
+from ..models import Block, BlockFormat, BlockKind, BlockVersion, ChildrenList, Project
 from . import utils
 
 logger = logging.getLogger()
@@ -16,14 +16,14 @@ class LatexArticle:
     With the abilty to fetch, localize its assets and write itself to file.
     """
 
-    def __init__(self, session: Session, project_id: str, article_id: str):
+    def __init__(self, session: Session, project_id: Union[str, Project], article_id: str):
         self.session = session
         self.project_id = project_id
         self.article_id = article_id
-        self.block = None
-        self.version = None
-        self.children = None
-        self.content = ""
+        self.block: Block = None
+        self.version: BlockVersion = None
+        self.children: ChildrenList = None
+        self.content: str = ""
         # TODO obvious one to centralise in project or someway
         self.users = []
 
@@ -104,8 +104,11 @@ class LatexArticle:
         TODO: this is turning into a double dispatchy thing, maybe article just holds a
         reference to the project
         """
+        logging.info("Localizing referenced content")
         self._localize_authors(session)
+        logging.info("Localized authors")
         self._localize_content(session, assets_folder, reference_list)
+        logging.info("Localized content and references")
 
     def write(self, filepath: str):
         with open(filepath, "w+") as file:
@@ -129,15 +132,23 @@ class LatexArticle:
         concatenated_content = ""
         for child in self.children:
             if child.kind == BlockKind.content:
-                logger.info("Content Block")
-                content = utils.localize_images_from_content_block(
-                    self.session, assets_folder, child.content
-                )
-                content = utils.localize_references_from_content_block(
-                    session, reference_list, content
-                )
+                logger.info("Found: Content Block")
+                try:
+                    content = utils.localize_images_from_content_block(
+                        self.session, assets_folder, child.content
+                    )
+                except ValueError as err:
+                    logging.error(f"Caught error trying to localize images for block {str(child.id)}, skipping")
+                    logging.error(err)
+                try:
+                    content = utils.localize_references_from_content_block(
+                        session, reference_list, content
+                    )
+                except ValueError as err:
+                    logging.error(f"Caught error trying to localize references for block {str(child.id)}, skipping")
+                    logging.error(err)
             elif child.kind == BlockKind.output:
-                logger.info(f"Output Block - num outputs: {len(child.outputs)}")
+                logger.info(f"Found: Output Block - num outputs: {len(child.outputs)}")
                 content = utils.localize_images_from_output_block(assets_folder, child)
             else:
                 logger.warning(f"Can't process block with kind:{child.kind} yet")
