@@ -220,12 +220,15 @@ def localize_references_from_content_block(
 
         if existing_reference is None:
             url = block_hash_to_url(block_path)
+            logging.info(f"fetching reference block {url}")
             block = get_model(session, url, Block)
+            logging.info("got reference block")
 
             # get latest version
-            version = get_model(
-                session, f"{url}/versions/{block.latest_version}?format=bibtex"
-            )
+            version_url = f"{url}/versions/{block.latest_version}?format=bibtex"
+            logging.info(f"fetching reference block {version_url}")
+            version = get_model(session, version_url)
+            logging.info("got reference version")
 
             # update the list
             local_tag, plain_tag = parse_cite_tag_from_version(version.content)
